@@ -278,7 +278,6 @@ void KHangMan::revealCurrentWord()
 void KHangMan::calculateNetScore()
 {
     m_netScore = ( m_winCount - m_lossCount ) * m_scoreMultiplyingFactor;
-    qDebug() << "Net Score = " << m_netScore;
     emit netScoreChanged();
 }
 
@@ -383,6 +382,20 @@ QString KHangMan::backgroundUrl()
     return QString();
 }
 
+QColor KHangMan::currentThemeLetterColor()
+{
+    // Default to white letters
+    QColor color = "white";
+    QStringList themes = m_themeFactory.getNames();
+    int index = themes.indexOf(Prefs::theme());
+    KHMTheme *theme = m_themeFactory.buildTheme(index);
+    if (theme) {
+        color = theme->letterColor();
+    }
+
+    return color;
+}
+
 QStringList KHangMan::categories()
 {
     return m_titleLevels.keys();
